@@ -1,9 +1,16 @@
 from __future__ import annotations
-from dataclasses import asdict
+
 from abc import abstractmethod, ABC
-from typing import List, Tuple, Type
-import pandas as pd
 from copy import deepcopy
+from dataclasses import asdict
+from typing import List, Tuple, Type, TYPE_CHECKING, Dict
+
+import numpy as np
+import pandas as pd
+
+if TYPE_CHECKING:
+    from reamber.base.Timed import Timed
+
 
 """ Criterion
 The derived object must be:
@@ -29,6 +36,9 @@ class TimedList(ABC):
         if args: list.__init__(*args)
         else: list.__init__([])
 
+    @abstractmethod
+    def __len__(self): ...
+
     @abstractmethod
     def data(self) -> List:
         """ The method to grab the data from derived classes """
@@ -59,8 +69,8 @@ class TimedList(ABC):
         :param inplace: Whether to just modify this instance or return a modified copy
         :return: Returns a modified copy if not inplace
         """
-        if inplace: self.__init__(sorted(self.data(), key=lambda tp: tp.offset, reverse=reverse))
-        else: return self._upcast(sorted(self.data(), key=lambda tp: tp.offset, reverse=reverse))
+        if inplace: self.__init__(sorted(self.data(), reverse=reverse))
+        else: return self._upcast(sorted(self.data(), reverse=reverse))
 
     def between(self, lowerBound, upperBound, includeEnds=True, inplace: bool = False) -> TimedList:
         """ Trims the list between specified bounds
@@ -138,7 +148,7 @@ class TimedList(ABC):
     def addOffset(self, by: float, inplace: bool = False) -> TimedList:
         """ Adds offset to all object
 
-        :param by: The offset to move by
+        :param by: The offset to add by
         :param inplace: Whether to just modify this instance or return a modified copy
         :return: Returns a modified copy if not inplace
         """
@@ -150,9 +160,9 @@ class TimedList(ABC):
         if not inplace: return self._upcast(d)
 
     def multOffset(self, by: float, inplace: bool = False) -> TimedList:
-        """ Adds offset to all object
+        """ Multiplies offset to all object
 
-        :param by: The offset to move by
+        :param by: The offset to multiply by
         :param inplace: Whether to just modify this instance or return a modified copy
         :return: Returns a modified copy if not inplace
         """
@@ -206,25 +216,64 @@ class TimedList(ABC):
         last = self.lastOffset()
         return self.addOffset(to - last, inplace=inplace)
 
-#
-# def generateAbc(singularType: Type = None, data=True, upcast=True):
-#     """ This factory creates a decorator that sets the basic necessities for anything deriving from a mapobjBase
-#     It adds __init__, data, and _upcast
-#     :param singularType: This must be declared if data is true
-#     :param data: Default True, generates the data
-#     :param upcast: Default True, generates the upcast
-#     :return: """
-#
-#     def wrapper(cls):
-#         def _data(self) -> List[singularType]:
-#             return self
-#
-#         def _upcast(self, m: List = None) -> cls:
-#             if m is None: m = []
-#             return cls(m)
-#
-#         if data:   setattr(cls, 'data', _data)
-#         if upcast: setattr(cls, '_upcast', _upcast)
-#
-#         return cls
-#     return wrapper
+    def activity(self, lastOffset: float or None = None):
+        """ Calculates how long each Timed Object is active. Implicitly sorts object by offset
+
+        For example:
+
+        The algorithm calculates this::
+
+            SEC 1   2   3   4   5   6   7   8   9
+            BPM 100 ------> 200 --> 300 -------->
+
+        returns [(Timed<1>, 3000), (Timed<2>, 2000), (Timed<3>, 3000)]
+
+        :param lastOffset: Last offset, if None, uses Timed.lastOffset()
+        :return: A List of Tuples in the format [(Timed, Activity In ms), ...]
+        """
+
+        if lastOffset is None: lastOffset = self.lastOffset()
+
+        # Describes the BPM and Length of it active
+        # e.g. [(120.0, 2000<ms>), (180.0, 1000<ms>), ...]
+        acts: List[Tuple[Timed, float]] = []
+
+        for obj in self.sorted(reverse=True).data():
+            if obj.offset >= lastOffset:
+                acts.append((obj, 0.0))  # If the BPM doesn't cover any notes it is inactive
+            else:
+                acts.append((obj, lastOffset - obj.offset))
+                lastOffset = obj.offset
+        return list(reversed(acts))
+
+    def rollingDensity(self, window: float, stride: float = None,
+                       firstOffset: float = None, lastOffset: float = None) -> Dict[int, int]:
+        """ Returns the Density Dictionary
+
+        :param window: The window to search in milliseconds.
+        :param stride: The stride length of each search in milliseconds, if None, stride = window
+        :param firstOffset: The first offset to start search on. If None, firstOffset will be used.
+        :param lastOffset: The last offset to end search on. If None, lastOffset will be used. \
+            (The search will intentionally exceed if it doesn't fit.)
+        :return: Dictionary of offset as key and count as value
+        """
+        if stride is None:
+            stride = window
+
+        ar = np.asarray(self.offsets())
+
+        if len(self) == 0: return {a: 0 for a in range(int(firstOffset if firstOffset else 0),
+                                                       int(lastOffset if lastOffset else 0),
+                                                       int(stride))}
+        first, last = self.firstLastOffset()
+        if firstOffset is not None: first = firstOffset
+        if lastOffset is not None: last = lastOffset
+
+        counts: Dict[int, int] = {}
+
+        for i, j in zip(range(int(first), int(last), int(stride)),
+                        range(int(first + window), int(last + window), int(stride))):
+            counts[i] = np.count_nonzero((ar >= i) & (ar < j))
+
+        return counts
+
