@@ -1,10 +1,12 @@
 from __future__ import annotations
-from reamber.sm.lists.notes.SMNoteList import SMNoteList
-from reamber.sm.SMMineObj import SMMineObj
+
 from typing import List
 
+from reamber.sm.SMMine import SMMine
+from reamber.sm.lists.notes.SMNoteList import SMNoteList
 
-class SMMineList(List[SMMineObj], SMNoteList):
+
+class SMMineList(List[SMMine], SMNoteList):
 
     def _upcast(self, objList: List = None) -> SMMineList:
         """ This is to facilitate inherited functions to work
@@ -14,5 +16,5 @@ class SMMineList(List[SMMineObj], SMNoteList):
         """
         return SMMineList(objList)
 
-    def data(self) -> List[SMMineObj]:
+    def data(self) -> List[SMMine]:
         return self
