@@ -15,30 +15,27 @@ class TestOsuToQua(unittest.TestCase):
     # @profile
     def test_osu1(self):
         # Complex BPM Points
-        osu = OsuMap()
-        osu.readFile(OSU_CARAVAN)
+        osu = OsuMap.readFile(OSU_CARAVAN)
 
         qua = OsuToQua.convert(osu)
-        qua.writeFile("out.qua")
+        # qua.writeFile("out.qua")
 
     # @profile
     def test_osu2(self):
         # Stops
-        osu = OsuMap()
-        osu.readFile(OSU_ESCAPES)
+        osu = OsuMap.readFile(OSU_ESCAPES)
 
         qua = OsuToQua.convert(osu)
-        qua.writeFile("out.qua")
+        # qua.writeFile("out.qua")
 
     # @profile
     def test_osu3(self):
         # Complex BPM
-        osu = OsuMap()
-        osu.readFile(OSU_GRAVITY)
+        osu = OsuMap.readFile(OSU_GRAVITY)
 
         qua = OsuToQua.convert(osu)
         qua.music = "Gravity.mp3"
-        qua.writeFile("out.qua")
+        # qua.writeFile("out.qua")
 
 
 if __name__ == '__main__':
