@@ -1,6 +1,6 @@
 import unittest
-from reamber.algorithms.generate.sv.SvSequence import SvSequence,SvObj
-from reamber.algorithms.generate.sv.SvPkg import SvPkg
+
+from reamber.algorithms.generate.sv.SvSequence import SvSequence
 
 
 class TestSvSequence(unittest.TestCase):
@@ -11,8 +11,5 @@ class TestSvSequence(unittest.TestCase):
         seq.rescale(300, 800, inplace=True)
 
 
-        pass
-
-
 if __name__ == '__main__':
     unittest.main()
